==> release.dxp.api-7.3.10.1.jar: META-INF/resources/data_layout_builder/js/plugins/fields-sidebar/components/FieldsSidebarSettingsBody.es.js <==
Liferay.Loader.define("data-engine-taglib@2.5.24/data_layout_builder/js/plugins/fields-sidebar/components/FieldsSidebarSettingsBody.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'dynamic-data-mapping-form-renderer', 'frontend-js-react-web$react', '../../../AppContext.es', '../../../actions.es', '../../../data-layout-builder/DataLayoutBuilderContext.es', '../../../utils/settingsForm.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;

    var _icon = require("@frontend-taglib-clay$clayui/icon");

    var _dynamicDataMappingFormRenderer = require("dynamic-data-mapping-form-renderer");

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _AppContext = _interopRequireDefault(require("../../../AppContext.es"));

    var _actions = require("../../../actions.es");

    var _DataLayoutBuilderContext = _interopRequireDefault(require("../../../data-layout-builder/DataLayoutBuilderContext.es"));

    var _settingsForm = require("../../../utils/settingsForm.es");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    function _default() {
      var spritemap = (0, _react.useContext)(_icon.ClayIconSpriteContext);

      var _useContext = (0, _react.useContext)(_DataLayoutBuilderContext.default),
          _useContext2 = _slicedToArray(_useContext, 1),
          dataLayoutBuilder = _useContext2[0];

      var _useContext3 = (0, _react.useContext)(_AppContext.default),
          _useContext4 = _slicedToArray(_useContext3, 2),
          _useContext4$ = _useContext4[0],
          config = _useContext4$.config,
          dataRules = _useContext4$.dataLayout.dataRules,
          editingLanguageId = _useContext4$.editingLanguageId,
          focusedCustomObjectField = _useContext4$.focusedCustomObjectField,
          focusedField = _useContext4$.focusedField,
          dispatch = _useContext4[1];

      var _useState = (0, _react.useState)(0),
          _useState2 = _slicedToArray(_useState, 2),
          activePage = _useState2[0],
          setActivePage = _useState2[1];

      var customObjectFieldSettingsContext = focusedCustomObjectField.settingsContext;
      var fieldSettingsContext = focusedField.settingsContext;
      var hasFocusedCustomObjectField = !!customObjectFieldSettingsContext;
      var settingsContext = hasFocusedCustomObjectField ? customObjectFieldSettingsContext : fieldSettingsContext;
      var filteredSettingsContext = (0, _react.useMemo)(function () {
        return (0, _settingsForm.getFilteredSettingsContext)({
          config: config,
          editingLanguageId: editingLanguageId,
          settingsContext: settingsContext
        });
      }, [config, editingLanguageId, settingsContext]);

      var dispatchEvent = function dispatchEvent(type, payload) {
        if (hasFocusedCustomObjectField && type === 'fieldEdited') {
          dispatch({
            payload: payload,
            type: _actions.EDIT_CUSTOM_OBJECT_FIELD
          });
        } else if (!hasFocusedCustomObjectField) {
          dataLayoutBuilder.dispatch(type, payload);
        }
      };

      (0, _react.useEffect)(function () {
        if (activePage > filteredSettingsContext.pages.length - 1) {
          setActivePage(0);
        }
      }, [filteredSettingsContext, activePage, setActivePage]);
      return (/*#__PURE__*/_react.default.createElement("form", {
          onSubmit: function onSubmit(event) {
            return event.preventDefault();
          }
        }, /*#__PURE__*/_react.default.createElement(_dynamicDataMappingFormRenderer.FormProvider, {
          onEvent: function onEvent(type, payload) {
            switch (type) {
              case _dynamicDataMappingFormRenderer.EVENT_TYPES.CHANGE_ACTIVE_PAGE:
                setActivePage(payload.value);
                break;

              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_BLUR:
              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_CHANGE:
                dispatchEvent(type, {
                  editingLanguageId: settingsContext.editingLanguageId,
                  propertyName: payload.fieldInstance.fieldName,
                  propertyValue: payload.value
                });
                break;

              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_EVALUATED:
                dispatchEvent('focusedFieldEvaluationEnded', {
                  settingsContext: _objectSpread(_objectSpread({}, settingsContext), {}, {
                    pages: payload
                  })
                });
                break;

              default:
                break;
            }
          },
          value: _objectSpread(_objectSpread({}, filteredSettingsContext), {}, {
            activePage: activePage,
            builderRules: dataRules,
            editable: true,
            editingLanguageId: editingLanguageId,
            spritemap: spritemap
          })
        }, function (props) {
          return (/*#__PURE__*/_react.default.createElement(_dynamicDataMappingFormRenderer.Pages, props)
          );
        }))
      );
    }
    //# sourceMappingURL=FieldsSidebarSettingsBody.es.js.map
  }
});
//# sourceMappingURL=FieldsSidebarSettingsBody.es.js.map

==> release.dxp.api-7.3.10.3.jar: META-INF/resources/data_layout_builder/js/plugins/fields-sidebar/components/FieldsSidebarSettingsBody.es.js <==
Liferay.Loader.define("data-engine-taglib@2.5.31/data_layout_builder/js/plugins/fields-sidebar/components/FieldsSidebarSettingsBody.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'dynamic-data-mapping-form-renderer', 'frontend-js-react-web$react', '../../../AppContext.es', '../../../actions.es', '../../../data-layout-builder/DataLayoutBuilderContext.es', '../../../utils/settingsForm.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;

    var _icon = require("@frontend-taglib-clay$clayui/icon");

    var _dynamicDataMappingFormRenderer = require("dynamic-data-mapping-form-renderer");

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _AppContext = _interopRequireDefault(require("../../../AppContext.es"));

    var _actions = require("../../../actions.es");

    var _DataLayoutBuilderContext = _interopRequireDefault(require("../../../data-layout-builder/DataLayoutBuilderContext.es"));

    var _settingsForm = require("../../../utils/settingsForm.es");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    function _default() {
      var spritemap = (0, _react.useContext)(_icon.ClayIconSpriteContext);

      var _useContext = (0, _react.useContext)(_DataLayoutBuilderContext.default),
          _useContext2 = _slicedToArray(_useContext, 1),
          dataLayoutBuilder = _useContext2[0];

      var _useContext3 = (0, _react.useContext)(_AppContext.default),
          _useContext4 = _slicedToArray(_useContext3, 2),
          _useContext4$ = _useContext4[0],
          config = _useContext4$.config,
          dataRules = _useContext4$.dataLayout.dataRules,
          editingLanguageId = _useContext4$.editingLanguageId,
          focusedCustomObjectField = _useContext4$.focusedCustomObjectField,
          focusedField = _useContext4$.focusedField,
          dispatch = _useContext4[1];

      var _useState = (0, _react.useState)(0),
          _useState2 = _slicedToArray(_useState, 2),
          activePage = _useState2[0],
          setActivePage = _useState2[1];

      var customObjectFieldSettingsContext = focusedCustomObjectField.settingsContext;
      var fieldSettingsContext = focusedField.settingsContext,
          fieldType = focusedField.type;
      var hasFocusedCustomObjectField = !!customObjectFieldSettingsContext;
      var settingsContext = hasFocusedCustomObjectField ? customObjectFieldSettingsContext : fieldSettingsContext;
      var filteredSettingsContext = (0, _react.useMemo)(function () {
        return (0, _settingsForm.getFilteredSettingsContext)({
          config: config,
          editingLanguageId: editingLanguageId,
          fieldType: fieldType,
          settingsContext: settingsContext
        });
      }, [config, editingLanguageId, settingsContext, fieldType]);

      var dispatchEvent = function dispatchEvent(type, payload) {
        if (hasFocusedCustomObjectField && type === 'fieldEdited') {
          dispatch({
            payload: payload,
            type: _actions.EDIT_CUSTOM_OBJECT_FIELD
          });
        } else if (!hasFocusedCustomObjectField) {
          dataLayoutBuilder.dispatch(type, payload);
        }
      };

      (0, _react.useEffect)(function () {
        if (activePage > filteredSettingsContext.pages.length - 1) {
          setActivePage(0);
        }
      }, [filteredSettingsContext, activePage, setActivePage]);
      return (/*#__PURE__*/_react.default.createElement("form", {
          onSubmit: function onSubmit(event) {
            return event.preventDefault();
          }
        }, /*#__PURE__*/_react.default.createElement(_dynamicDataMappingFormRenderer.FormProvider, {
          onEvent: function onEvent(type, payload) {
            switch (type) {
              case _dynamicDataMappingFormRenderer.EVENT_TYPES.CHANGE_ACTIVE_PAGE:
                setActivePage(payload.value);
                break;

              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_BLUR:
              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_CHANGE:
                dispatchEvent(type, {
                  editingLanguageId: settingsContext.editingLanguageId,
                  propertyName: payload.fieldInstance.fieldName,
                  propertyValue: payload.value
                });
                break;

              case _dynamicDataMappingFormRenderer.EVENT_TYPES.FIELD_EVALUATED:
                dispatchEvent('focusedFieldEvaluationEnded', {
                  settingsContext: _objectSpread(_objectSpread({}, settingsContext), {}, {
                    pages: payload
                  })
                });
                break;

              default:
                break;
            }
          },
          value: _objectSpread(_objectSpread({}, filteredSettingsContext), {}, {
            activePage: activePage,
            builderRules: dataRules,
            editable: true,
            editingLanguageId: editingLanguageId,
            spritemap: spritemap
          })
        }, function (props) {
          return (/*#__PURE__*/_react.default.createElement(_dynamicDataMappingFormRenderer.Pages, props)
          );
        }))
      );
    }
    //# sourceMappingURL=FieldsSidebarSettingsBody.es.js.map
  }
});
//# sourceMappingURL=FieldsSidebarSettingsBody.es.js.map
